ShieldHeader class

Parsed header for an encrypted asset payload.

Constructors

ShieldHeader({required int version, required bool compressed, required int algorithm, required int chunkSize, required int originalLength, required Uint8List baseIv})

Properties

algorithm int
final
baseIv Uint8List
final
chunkSize int
final
compressed bool
final
hashCode int
The hash code for this object.
no setterinherited
originalLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited