ShieldCrypto class
Native AES‑256‑GCM encryption/decryption with V3 chunked header.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decrypt(
Uint8List encryptedBytes, Uint8List keyBytes, {int cryptoWorkers = -1, int zstdWorkers = -1}) → Uint8List - Decrypts bytes produced by encrypt.
-
encrypt(
Uint8List plainBytes, Uint8List keyBytes, {bool compress = true, int compressionLevel = 3, int chunkSize = 256 * 1024, int cryptoWorkers = -1, int zstdWorkers = -1}) → Uint8List - Encrypts bytes with AES‑256‑GCM and optional compression.
-
parseHeader(
Uint8List encryptedBytes) → ShieldHeader - Parses the encrypted asset header (V3 only).